| `getting_started`_ | `connecting`_ | `installing`_ | `license`_ | `documentation <https://geoana.simpeg.xyz/>`_ |

geoana
======

.. image:: https://img.shields.io/pypi/v/geoana.svg
    :target: https://pypi.python.org/pypi/geoana
    :alt: Latest PyPI version

.. image:: https://anaconda.org/conda-forge/geoana/badges/version.svg
    :target: https://anaconda.org/conda-forge/geoana
    :alt: Latest conda-forge version

.. image:: https://img.shields.io/github/license/simpeg/geoana.svg
    :target: https://github.com/simpeg/geoana/blob/main/LICENSE
    :alt: MIT license

.. image:: https://codecov.io/gh/simpeg/geoana/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/simpeg/geoana
    :alt: Coverage status


`geoana` is a collection of (mostly) analytic functions in geophysics. We take an object oriented
approach with the aim of having users be able to readily interact with the functions using `Jupyter <https://jupyter.org>`_


.. _getting_started:

Getting started
---------------

- If you do not already have python installed, we recommend downloading and installing it through `anaconda <https://www.anaconda.com/download/>`_
- `installing`_ `geoana`
- Browse the `gallery <https://geoana.simpeg.xyz/auto_examples/>`_ for ideas and example usage
- Read the `documentation <https://geoana.simpeg.xyz/>`_ for more information on the library and what it can do

.. - See the `contributor guide` and `code of conduct` if you are interested in helping develop or maintain geoana

.. _connecting:

Connecting with the community
-----------------------------

geoana is a part of the larger `SimPEG <https://simpeg.xyz>`_ ecosystem. There are several avenues for connecting:

- a discourse website for questions: https://simpeg.discourse.group/
- a youtube channel where meeting recordings are posted: `GeoSci.xyz <https://www.youtube.com/channel/UCBrC4M8_S4GXhyHht7FyQqw>`_
- a slack group for real-time chat with users and developers of SimPEG: http://slack.simpeg.xyz/

.. _installing:

Installing
----------

**geoana** is on conda-forge

.. code:: shell

    conda install -c conda-forge geoana

**geoana** is available on `pypi <https://pypi.org/project/geoana/>`_ and can be installed by opening a command window and running:

.. code::

    pip install geoana


To install from source, you can

.. code::

    git clone https://github.com/simpeg/geoana.git
    python setup.py install

.. _license:

License
-------

geoana is licensed under the `MIT license <https://github.com/simpeg/geoana/blob/master/LICENSE>`_ .
